plotEISA takes the return value from runEISA and generates a scatterplot of intronic versus exonic changes.

plotEISA(
  x,
  contrast = c("ExIn", "none"),
  minLfc = NULL,
  maxFDR = 0.05,
  genecolors = c("#E41A1C", "#497AB3", "#222222"),
  ...
)

Arguments

x

list with EISA results, typically the return value from runEISA

contrast

one of "ExIn" or "none". If "ExIn" (the default), genes that significantly differ between exonic and intronic changes are highlighted. "none" turns off gene highlighting.

minLfc

NULL or numeric(1) with the minimal absolute log2 fold change to color a gene. If NULL (the default), no fold changes are not used to select genes for highlighting.

maxFDR

numeric(1) with maximal false discovery rate for gene highlighting.

genecolors

Vector of length three specifying the colors to use for genes that are significantly up, down or unchanged.

...

Currently not used, provided for backward compatibility.

Value

A ggplot object.

Author

Michael Stadler, Charlotte Soneson

Examples

  # see the help for runEISA() for a full example