plotEISA takes the return value from runEISA
and generates a scatterplot of intronic versus exonic changes.
list with EISA results, typically the return value from
runEISA
one of "ExIn" or "none". If "ExIn"
(the default), genes that significantly differ between exonic and
intronic changes are highlighted. "none" turns off gene
highlighting.
NULL or numeric(1) with the minimal absolute log2
fold change to color a gene. If NULL (the default), no fold changes
are not used to select genes for highlighting.
numeric(1) with maximal false discovery rate for gene
highlighting.
Vector of length three specifying the colors to use for genes that are significantly up, down or unchanged.
Currently not used, provided for backward compatibility.
A ggplot object.
# see the help for runEISA() for a full example